void errLeds(void)
{
  pinMode(LED_BUILTIN, OUTPUT);
  digitalWrite(LED_BUILTIN, HIGH);
  delay(100);
  digitalWrite(LED_BUILTIN, LOW);
  delay(100);
}

void printTTNDebug() {
  Serial.print("ttn.isBusy(): ");
  Serial.print(ttn.isBusy());
  Serial.print(" ttn.isLink(): ");
  Serial.print(ttn.isLink());

  Serial.println();
}

void message(uint8_t *payload, size_t size, uint8_t port)
{
  Serial.println("Received " + String(size) + " bytes on port " + String(port));
  switch (port) {
    case 1:
      break;
  }
}

void updateNeoPixel(){
  if(millis() - NeoPixelUpdateLoopMillis > NeoPixelUpdateLoopInterval) {
    NeoPixelUpdateLoopMillis = millis();
    double warningValue = 800;
    double criticalValue = 1500;
    double steps = 2000/strip.numPixels();
    float co2 = iaqSensor.co2Equivalent;
    for(int i=0; i<strip.numPixels(); i++) {
      #ifndef LEDALWAYSON
      if(co2 >= steps*(i+1)) {
      #endif
        if(co2 >= criticalValue) strip.setPixelColor(i, 255, 0, 0);
        else if(co2 >= warningValue) strip.setPixelColor(i, 255,   165,   0);
        else if(co2 < warningValue) strip.setPixelColor(i, 0,   255,   0);
      #ifndef LEDALWAYSON
      }
      else {
        strip.setPixelColor(i, 0,   0,   0);
      }
      #endif
      strip.show();
    }
  }
}



// Helper function definitions
void checkIaqSensorStatus(void)
{
  if (iaqSensor.status != BSEC_OK) {
    if (iaqSensor.status < BSEC_OK) {
      output = "BSEC error code : " + String(iaqSensor.status);
      Serial.println(output);
      for (;;)
        errLeds(); /* Halt in case of failure */
    } else {
      output = "BSEC warning code : " + String(iaqSensor.status);
      Serial.println(output);
    }
  }

  if (iaqSensor.bme680Status != BME680_OK) {
    if (iaqSensor.bme680Status < BME680_OK) {
      output = "BME680 error code : " + String(iaqSensor.bme680Status);
      Serial.println(output);
      for (;;)
        errLeds(); /* Halt in case of failure */
    } else {
      output = "BME680 warning code : " + String(iaqSensor.bme680Status);
      Serial.println(output);
    }
  }
}

#ifdef USE_DISPLAY

void updateDisplay() {
  if(millis() - DisplayUpdateLoopMillis > DisplayUpdateLoopInterval) {
    DisplayUpdateLoopMillis = millis();
    char displayText[256];
    u8g2.clearBuffer();

    char tempString[10];
    dtostrf(iaqSensor.temperature, 4, 2, tempString);
    sprintf(displayText, "Temp: %s", tempString);
    u8g2.drawStr(0,10,displayText);

    char humidString[10];
    dtostrf(iaqSensor.humidity, 4, 2, humidString);
    sprintf(displayText, "Humidity: %s", humidString);
    u8g2.drawStr(0,20,displayText);

    char co2String[10];
    dtostrf(iaqSensor.co2Equivalent, 4, 2, co2String);
    sprintf(displayText, "CO2-Equivalent: %s", "");
    u8g2.drawStr(0,30,displayText);
    sprintf(displayText, "%20s", co2String);
    u8g2.drawStr(0,40,displayText);

    sprintf(displayText, "ttn.isBusy(): %d", ttn.isBusy());
    u8g2.drawStr(0,50,displayText);

    sprintf(displayText, "ttn.isLink(): %d", ttn.isLink());
    u8g2.drawStr(0,60,displayText);

    u8g2.sendBuffer();
  }
}

void setupDisplay() {
  u8g2.begin();
  u8g2.setFont(u8g2_font_courB08_tr);	// choose a suitable font
  updateDisplay();
}

#endif

